@@ -1,6 +1,6 @@
 ###    Test of independence based on maximally selected statistics
 ###
-### Copyright 2006-05 Anne-Laure Boulesteix 
+### Copyright 2006-09 Anne-Laure Boulesteix 
 ###
 ### 
 ###
@@ -65,5 +65,12 @@ if (type=="cat")
  return(p)
  }
 
+if (type=="ord2")
+ {
+ p<-Ford2(c=maxselcrit,n0=n0,n1=n1,A=A,statistic=statistic)
+ return(p)
+ }
+
+
 }
 
